@@ -3,6 +3,7 @@ package cmd
 import (
 	"fmt"
 	"os"
+	"path/filepath"
 	"strings"
 	"time"
 
@@ -10,6 +11,7 @@ import (
 	"github.com/abiosoft/colima/cmd/root"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/config/configmanager"
+	"github.com/abiosoft/colima/daemon/process/gvproxy"
 	"github.com/abiosoft/colima/embedded"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/container/docker"
@@ -92,6 +94,7 @@ const (
 	defaultDisk              = 60
 	defaultKubernetesVersion = kubernetes.DefaultVersion
 	defaultMountType         = "sshfs"
+	defaultNetworkDriver     = gvproxy.Name
 )
 
 var startCmdArgs struct {
@@ -102,15 +105,18 @@ var startCmdArgs struct {
 		LegacyKubernetes bool // for backward compatibility
 		Edit             bool
 		Editor           string
+		ActivateRuntime  bool
 	}
 }
 
 func init() {
 	runtimes := strings.Join(environment.ContainerRuntimes(), ", ")
+	networkDrivers := strings.Join([]string{"slirp", gvproxy.Name}, ", ")
 	defaultArch := string(environment.HostArch().Value())
 
 	root.Cmd().AddCommand(startCmd)
 	startCmd.Flags().StringVarP(&startCmdArgs.Runtime, "runtime", "r", docker.Name, "container runtime ("+runtimes+")")
+	startCmd.Flags().BoolVar(&startCmdArgs.Flags.ActivateRuntime, "activate", true, "set as active Docker/Kubernetes context on startup")
 	startCmd.Flags().IntVarP(&startCmdArgs.CPU, "cpu", "c", defaultCPU, "number of CPUs")
 	startCmd.Flags().StringVar(&startCmdArgs.CPUType, "cpu-type", "", "the CPU type, options can be checked with 'qemu-system-"+defaultArch+" -cpu help'")
 	startCmd.Flags().IntVarP(&startCmdArgs.Memory, "memory", "m", defaultMemory, "memory in GiB")
@@ -119,6 +125,7 @@ func init() {
 
 	// network
 	if util.MacOS() {
+		startCmd.Flags().StringVar(&startCmdArgs.Network.Driver, "network-driver", defaultNetworkDriver, "network driver to use ("+networkDrivers+")")
 		startCmd.Flags().BoolVar(&startCmdArgs.Network.Address, "network-address", false, "assign reachable IP address to the VM")
 	}
 
@@ -154,11 +161,21 @@ func init() {
 func mountsFromFlag(mounts []string) []config.Mount {
 	mnts := make([]config.Mount, len(mounts))
 	for i, mount := range mounts {
-		str := strings.SplitN(mount, ":", 2)
-		mnts[i] = config.Mount{
-			Location: str[0],
-			Writable: len(str) >= 2 && str[1] == "w",
+		str := strings.SplitN(mount, ":", 3)
+		mnt := config.Mount{Location: str[0]}
+
+		if len(str) > 1 {
+			if filepath.IsAbs(str[1]) {
+				mnt.MountPoint = str[1]
+			} else if str[1] == "w" {
+				mnt.Writable = true
+			}
 		}
+		if len(str) > 2 && str[2] == "w" {
+			mnt.Writable = true
+		}
+
+		mnts[i] = mnt
 	}
 	return mnts
 }
@@ -179,6 +196,7 @@ func prepareConfig(cmd *cobra.Command) {
 
 	// convert cli to config file format
 	startCmdArgs.Mounts = mountsFromFlag(startCmdArgs.Flags.Mounts)
+	startCmdArgs.ActivateRuntime = &startCmdArgs.Flags.ActivateRuntime
 
 	// if there is no existing settings
 	if current.Empty() {
@@ -193,6 +211,8 @@ func prepareConfig(cmd *cobra.Command) {
 
 	// docker can only be set in config file
 	startCmdArgs.Docker = current.Docker
+	// provision scripts can only be set in config file
+	startCmdArgs.Provision = current.Provision
 
 	// use current settings for unchanged configs
 	// otherwise may be reverted to their default values.
@@ -235,7 +255,15 @@ func prepareConfig(cmd *cobra.Command) {
 	if !cmd.Flag("layer").Changed {
 		startCmdArgs.Layer = current.Layer
 	}
+	if !cmd.Flag("activate").Changed {
+		if current.ActivateRuntime != nil { // backward compatibility for `activate`
+			startCmdArgs.ActivateRuntime = current.ActivateRuntime
+		}
+	}
 	if util.MacOS() {
+		if !cmd.Flag("network-driver").Changed {
+			startCmdArgs.Network.Driver = current.Network.Driver
+		}
 		if !cmd.Flag("network-address").Changed {
 			startCmdArgs.Network.Address = current.Network.Address
 		}
